"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tf = require("@tensorflow/tfjs");
function balancedTrainValSplit(xs, ys, valSplit) {
    tf.util.assert(valSplit > 0 && valSplit < 1, "validationSplit is expected to be >0 and <1, " +
        ("but got " + valSplit));
    return tf.tidy(function () {
        var classIndices = ys.argMax(-1).dataSync();
        var indicesByClasses = [];
        for (var i = 0; i < classIndices.length; ++i) {
            var classIndex = classIndices[i];
            if (indicesByClasses[classIndex] == null) {
                indicesByClasses[classIndex] = [];
            }
            indicesByClasses[classIndex].push(i);
        }
        var numClasses = indicesByClasses.length;
        var trainIndices = [];
        var valIndices = [];
        indicesByClasses.map(function (classIndices) { return tf.util.shuffle(classIndices); });
        for (var i = 0; i < numClasses; ++i) {
            var classIndices_1 = indicesByClasses[i];
            var cutoff = Math.round(classIndices_1.length * (1 - valSplit));
            for (var j = 0; j < classIndices_1.length; ++j) {
                if (j < cutoff) {
                    trainIndices.push(classIndices_1[j]);
                }
                else {
                    valIndices.push(classIndices_1[j]);
                }
            }
        }
        var trainXs = tf.gather(xs, trainIndices);
        var trainYs = tf.gather(ys, trainIndices);
        var valXs = tf.gather(xs, valIndices);
        var valYs = tf.gather(ys, valIndices);
        return { trainXs: trainXs, trainYs: trainYs, valXs: valXs, valYs: valYs };
    });
}
exports.balancedTrainValSplit = balancedTrainValSplit;
//# sourceMappingURL=training_utils.js.map